@@ -1,23 +1,4 @@
-// The MIT License (MIT)
-
-// Copyright (c) 2020 наб <nabijaczleweli@nabijaczleweli.xyz>
-
-// Permission is hereby granted, free of charge, to any person obtaining a copy of
-// this software and associated documentation files (the "Software"), to deal in
-// the Software without restriction, including without limitation the rights to
-// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
-// the Software, and to permit persons to whom the Software is furnished to do so,
-// subject to the following conditions:
-
-// The above copyright notice and this permission notice shall be included in all
-// copies or substantial portions of the Software.
-
-// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
-// FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
-// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
-// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+// SPDX-License-Identifier: MIT
 
 
 #pragma once
@@ -32,8 +13,8 @@
 #include <variant>
 #include <vector>
 extern "C" {
-#include <efivar/efiboot.h>
-#include <efivar/efivar-dp.h>
+#include <efiboot.h>
+#include <efivar-dp.h>
 }
 
 namespace klapki {
@@ -63,7 +44,7 @@ namespace klapki::context {
 		std::set<std::pair<std::string, std::string>> deleted_files;  // path in ESP, basename
 
 		std::optional<std::string> allocate_kernel_variant(const config & cfg, state::state & state, std::string version, std::string var, std::string image_dir,
-		                                                   state::sha_t & image_sha, std::vector<std::pair<state::nonbase_dirname_t, state::shaa_t>> initrd_dirs,
+		                                                   sha_t & image_sha, std::vector<std::pair<state::nonbase_dirname_t, state::shaa_t>> initrd_dirs,
 		                                                   std::string image_basename, std::vector<std::pair<state::nonbase_dirname_t, std::string>> initrd_paths);
 		template <class F>
 		void purge_allocations(state::state & state, F && pred);
@@ -71,14 +52,19 @@ namespace klapki::context {
 
 		std::optional<std::string> propagate(const config & cfg, state::state & state);
 		std::optional<std::string> age(const config & cfg, state::state & state);
-		std::optional<std::string> wisen(const config & cfg, state::state & state);
-		std::optional<std::string> save(const config & cfg, state::state & state);
+		std::optional<std::string> wisen(const config & cfg, const state::state & state);
+		std::optional<std::string> save(const config & cfg, state::state & state, efidp_data * _test_esp_devpath_override = nullptr);
 		std::optional<std::string> commit(const config & cfg, state::state & state) const;  // Only updates file SHAs in state
 
-		static context derive(const config & cfg, state::state & input_state);
+		static context derive(const config & cfg, const state::state & output_state);
 	};
 
 	std::variant<state::state, std::string> resolve_state_context(const config & cfg, const state::state & input_state);
+
+
+	// common test support
+	bool operator==(const our_kernel & lhs, const our_kernel & rhs);
+	bool operator==(const fresh_kernel & lhs, const fresh_kernel & rhs);
 }
 
 
@@ -104,7 +90,7 @@ struct fmt::formatter<klapki::context::context> {
 	auto format(const klapki::context::context & context, FormatContext & ctx) {
 		auto out = ctx.out();
 
-		out = format_to(out, "{} of our kernels: [", context.our_kernels.size());
+		out = format_to(out, fngettext("{} of our kernels: [", "{} of our kernels: [", context.our_kernels.size()), context.our_kernels.size());
 
 		bool first = true;
 		for(auto && el : context.our_kernels) {
@@ -113,12 +99,12 @@ struct fmt::formatter<klapki::context::context> {
 				first  = false;
 			}
 
-			out = format_to(out, "  {:04X}: {}\n", el.first, el.second);
+			out = format_to(out, fgettext("  {:04X}: {}\n"), el.first, el.second);
 		}
 
 
-		out = format_to(out, "]\n"
-		                     "Fresh kernels: [");
+		out = format_to(out, fgettext("]\n"
+		                              "Fresh kernels: ["));
 
 		first = true;
 		for(auto && el : context.fresh_kernels) {
@@ -130,8 +116,8 @@ struct fmt::formatter<klapki::context::context> {
 			out = format_to(out, "  {}\n", el);
 		}
 
-		out = format_to(out, "]\n"
-		                     "Deleted files: [");
+		out = format_to(out, fgettext("]\n"
+		                              "Deleted files: ["));
 
 		first = true;
 		for(auto && el : context.deleted_files) {
