@@ -212,8 +212,8 @@ std::optional<std::string> klapki::context::context::save(const config & cfg, st
 			        if(rskern == std::end(state.statecfg.wanted_entries))
 				        throw __func__;
 
-			        if(lskern->version != rskern->version)
-				        return lskern->version > rskern->version;
+			        if(auto cmp = strverscmp(lskern->version.c_str(), rskern->version.c_str()); cmp)
+				        return cmp > 0;
 
 			        auto lvar = lskern->variant == "" ? -1 : std::find_if(std::begin(state.statecfg.variants), std::end(state.statecfg.variants), [&](auto && var) {
 				                                                 return var == lskern->variant;
