@@ -99,8 +99,8 @@ std::variant<klapki::state::state, std::string> klapki::state::state::load(const
 	klapki::state::state ret{};
 	bool saw_boot_order{}, saw_our_config{};
 	{
-		efi_guid_t * guid;
-		char * name_i;
+		efi_guid_t * guid{};
+		char * name_i{};
 		for(int err; (err = efi_get_next_variable_name(&guid, &name_i));)
 			if(err < 0)
 				return fmt::format("EFI load: iteration: {}", std::strerror(errno));
